<?php

namespace Drupal\linkit_sharepoint\Plugin\Linkit\Matcher;

use Drupal\linkit\MatcherBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Sharepoint matcher class.
 *
 * @Matcher(
 *   id = "sharepoint_matcher",
 *   label = @Translation("Sharepoint Matcher"),
 * )
 */
class SharepointMatcher extends MatcherBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getMatches($string) {
    $sp = \Drupal::service('linkit_sharepoint.sharepoint');
    $items = $sp->search($string);
    $matches = [];
    foreach ($items as $item) {
      $description = [];

      $confidentiality = $item->getProperty('Vertraulichkeitsstufe');
      $document_type = $item->getProperty('Dokumentart');
      $language = $item->getProperty('Sprache');
      $area = $item->getProperty('Bereich');

      if (!empty($confidentiality)) {
        $description[] = $this->t('Confidentiality: @label', [
          '@label' => $confidentiality['Label'],
        ]);
      }
      if (!empty($document_type)) {
        $description[] = $this->t('Document type: @document_type', [
          '@document_type' => $document_type['Label'],
        ]);
      }
      if (!empty($language)) {
        $description[] = $this->t('Language: @language', [
          '@language' => $language['Label'],
        ]);
      }
      if (!empty($area)) {
        $description[] = $this->t('Area: @area', [
          '@area' => $area['Label'],
        ]);
      }

      $description[] = $item->EncodedAbsUrl;

      $matches[] = [
        'title' => !empty($item->Title) ? $item->Title : urldecode(basename($item->EncodedAbsUrl)),
        'description' => implode('<br/>', $description),
        'path' => '/deliver/' . $item->Id,
        'group' => 'Sharepoint Documents',
      ];
    }
    return $matches;
  }

}
